@@ -167,6 +167,7 @@ class LogItemPickupFromLootBox(LogItemPickup):
 
     def from_dict(self):
         super().from_dict()
+        self.creator_id = self._data.get('creatorAccountId')
         self.team_id = self._data.get('ownerTeamId')
 
 
@@ -187,6 +188,18 @@ class LogObjectDestroy(Event):
             self._data.get('objectLocation', {}))
 
 
+class LogObjectInteraction(Event):
+
+    def from_dict(self):
+        super().from_dict()
+        self.character = objects.Character(self._data.get('character', {}))
+        self.object_type = self._data.get('objectType')
+        self.object_type_status = self._data.get('objectTypeStatus')
+        self.object_type_additional_info = self._data.get(
+            'objectTypeAdditionalInfo')
+        self.object_type_count = self._data.get('objectTypeCount')
+
+
 class LogVaultStart(Event):
 
     def from_dict(self):
@@ -378,3 +391,21 @@ class LogRedZoneEnded(Event):
     def from_dict(self):
         super().from_dict()
         self.drivers = self._data.get('drivers', [])
+
+
+class LogPhaseChange(Event):
+
+    def from_dict(self):
+        super().from_dict()
+        self.phase = self._data.get('phase')
+
+
+class LogPlayerUseThrowable(Event):
+
+    def from_dict(self):
+        super().from_dict()
+        self.attackId = self._data.get('attackId')
+        self.fire_weapon_stack_count = self._data.get('fireWeaponStackCount')
+        self.attacker = objects.Character(self._data.get('attacker', {}))
+        self.attack_type = self._data.get('attackType')
+        self.weapon = objects.Item(self._data.get('weapon', {}))
